@@ -2,15 +2,11 @@ package YAML::LibYAML::API::XS;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.14.0'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use XSLoader;
 XSLoader::load('YAML::LibYAML::API::XS', $VERSION);
 
-sub parse_events {
-    parse_string_events(@_);
-}
-
 1;
 
 __END__
